pub enum DeviceInfoError {
ReservedCapabilities,
MissingMemoryDomain,
ZeroLimit,
}Expand description
Invalid provider metadata discovered before any resource operation is invoked.
Variants
ReservedCapabilities
A capability whose semantics are still reserved was advertised.
MissingMemoryDomain
No provider-owned memory domain can be allocated.
ZeroLimit
A mandatory resource or byte limit is zero.