pub struct AllocatedBuffer<B> { /* private fields */ }Expand description
A newly allocated native buffer handle and its verified backing properties.
Device implementations should retain info in their object record and pass only buffer to
backend hot paths.
Implementations
Sourceimpl<B> AllocatedBuffer<B>
impl<B> AllocatedBuffer<B>
pub const fn new(buffer: B, info: BufferInfo) -> Self
pub const fn buffer(&self) -> &B
pub fn buffer_mut(&mut self) -> &mut B
pub const fn info(&self) -> BufferInfo
pub fn into_parts(self) -> (B, BufferInfo)